--[[ SayAltFt.lua 
	by boomerwing 
	Version 1.0 - 27 November, 2016
	TESTED  OpenTx v. 2.1.9

	This function watches the altimeter and announces passing through 100 foot increments
	It checks if the Altitude is a multiple of 100 ft and signals if so.  It signals
	both passing up through 100s of feet or down through 100s of feet.  If you pass through
    the 100 ft increments very fast the function will not detect it. (one reading x96 ft and
    the next x03 feet)
	Note 1: You must select whether you are using metric or imperial units in the Taranis 
	    but the companion simulator outputs in meters.
	Note 2: The companion Alt simulator provides an altitude assumed to be sea level reference.
	    If you set an altitude in the simulator, then reset the simulated TX altitude the 
		altitude shown on the simulated TX screen will be zeroed as though the simulated altitude 
		is showing the altitude of your flying field.  So, if you set the simulated altitude to
		50 meters, then reset the TX altimeter, the TX will assume you are starting your flight
		from an altitude of 50 meters above sea level but the display will show 0 feet.
		The alt input to the script is given with reference to the flying field altitude,
		not the simulated altitude input.
    Note 3: You need a Logical Switch and a Special Function to use this script.
	    eg.  L1   a>x    [i]Flg   0      --  L1 looks for a positive output from the script
		     L2   edge    L1    [0.0:<<]  -- L2 responds to the positive edge of L1
			 SF1   L2     Play Value   Alt       1x   -- SF1 responds to L2 active to Say Altitude

	INSTALLATION
1. Save script with .LUA extension, store in /SCRIPTS/MIXES folder on SD Card
2. Open Custom Scripts menu in the transmitter
3. Assign this script to empty slot
4. Open script, and test with alt input if you are using Companion with the inputs simulator.   You will
   see the Flag output change from negative to positive when altitude arrives at each desired increment.
5. Close Scripts menu
6. Check that [i]Flag appears in the mixer Src list and is available for Logical Switch
]]

local outputs = {"Flg"}
     --[[ This is seen as LUA1a in the Companion Logical Switch setup screen when you select input
          for the Logical Switch if your LUA script is LUA1
	   ]]


 local function run_func()
		  altNow = getValue("Alt")
		  modVal = altNow%100   --  look for 100 ft increments.  You can change this value
		  if modVal < 2 or modVal > 98 then  --  between x98 and y02
		     flg = 1024
		  else
		     flg = -1024
		  end
	   return flg
end
return {run=run_func, output=outputs}