--[[ SayAltTr.lua 
	by boomerwing 
	Version 1.0 - 26 February, 2017
	TESTED  OpenTx v. 2.1.9

	This function watches the altimeter and announces passing through set increments (Default 100-
    Feet or Meters depends on the setup of OpenTX Transmitter).  You set the increment value when
    you activate the script.  It presently defaults to increments of 100 but Min=40 and Max =100
    but you can change these values.
	It checks if the Altitude is a multiple of the set increment and signals if so.  It signals
	both passing up through through the increments or down.  If you pass through
    the increments very fast the function will not detect it. (one reading x86 ft and
    the next x03 feet)
	Note 1: You must select whether you are using metric or imperial units in the Taranis 
	    but the companion simulator outputs in meters.
	Note 2: The companion Alt simulator provides an altitude assumed to be sea level reference.
	    If you set an altitude in the simulator, then reset the simulated TX altitude the 
		altitude shown on the simulated TX screen will be zeroed as though the simulated altitude 
		is showing the altitude of your flying field.  So, if you set the simulated altitude to
		50 meters, then reset the TX altimeter, the TX will assume you are starting your flight
		from an altitude of 50 meters above sea level but the display will show 0 feet.
		The alt input to the script is given with reference to the flying field altitude,
		not the simulated altitude input.
    Note 3: You need a Logical Switch and a Special Function to use this script.
	    eg.  L1   a>x    [i]flg   0      --  L1 looks for a positive output from the script
		     L2   edge    L1    [0.0:<<]  -- L2 responds to the positive edge of L1
			 SF1   L2     Play Value   Alt       1x   -- SF1 responds to L2 active to Say Altitude

	INSTALLATION
1. Save script with .LUA extension, store in /SCRIPTS/MIXES folder on SD Card
2. Open Custom Scripts menu in the transmitter
3. Assign this script to empty slot
4. Open script, and test with alt input if you are using Companion with the inputs simulator.   You will
   see the Flag output change from negative to positive when altitude arrives at each desired increment.
5. Close Scripts menu
6. Check that [i]Flag appears in the mixer Src list and is available for Logical Switch
]]
local inputs = 
    {
        { "tra", VALUE, 40, 200, 100},		-- Value of transition point
    }


local outputs = {"flg"}
     --[[ This is seen as LUA1a in the Companion Logical Switch setup screen when you select input
          for the Logical Switch if your LUA script is LUA1
	   ]]


 local function run_func(tra)
		  altNow = getValue("Alt")
		  modVal = altNow%tra   --  The input value of "tra" sets the transition point
		  if modVal < 2 or modVal > (tra - 2) then  
		     flg = 1024
		  else
		     flg = -1024
		  end
	   return flg
end
return {run=run_func, output=outputs, input=inputs}